@@ -17,7 +17,7 @@ impl ToTypeDef for NapiConst {
       def: format!(
         "export const {}: {}",
         &self.js_name,
-        ty_to_ts_type(&self.type_name, false).0
+        ty_to_ts_type(&self.type_name, false, false).0
       ),
       js_mod: self.js_mod.to_owned(),
       js_doc: js_doc_from_comments(&self.comments),
